@@ -1,3 +1,5 @@
+# horizon checking may be too strict
+
 fetchPedonPC <- function(dsn) {
 	
 	# 1. load data in pieces
@@ -35,7 +37,7 @@ fetchPedonPC <- function(dsn) {
 	depths(f) <- pedon_id ~ hzdept + hzdepb
 	
 	# move site data into @site
-	site(f) <- ~ peiid + site_id + siteiid + hillslope_pos + x + y + datum + elev + slope + aspect + plantassocnm + bedrckdepth + bedrock_kind + bedrock_hardness + describer + psctopdepth + pscbotdepth + obs_date + pedon_purpose + pedon_type + pedlabsampnum
+	site(f) <- ~ peiid + site_id + siteiid + hillslope_pos + x + y + datum + elev_field + slope_field + aspect_field + plantassocnm + bedrckdepth + bedrock_kind + bedrock_hardness + describer + psctopdepth + pscbotdepth + obs_date + pedon_purpose + pedon_type + pedlabsampnum
 	
 	# 5. convert colors... in the presence of missing color data
 	f$soil_color <- rep(NA, times=nrow(horizons(f)))
