@@ -29,18 +29,18 @@ LEFT OUTER JOIN (SELECT * FROM dbo.MetadataDomainDetail WHERE dbo.MetadataDomain
 ORDER BY dmudesc;"
 	
 	# setup connection to our pedon database
-	channel <- odbcConnect('nasis_local', uid='NasisSqlRO', pwd='Re@d0n1y')
+	channel <- odbcConnect('nasis_local', uid='NasisSqlRO', pwd='nasisRe@d0n1y')
 	
 	# exec query
 	d <- sqlQuery(channel, q, stringsAsFactors=FALSE)
+
+	# close connection
+	odbcClose(channel)
 	
 	# test for no data
 	if(nrow(d) == 0)
 		stop('there are no NASIS components in your local database!')
 	
-	# close connection
-	odbcClose(channel)
-	
 	# done
 	return(d)
 }
@@ -51,7 +51,7 @@ get_component_horizon_data_from_NASIS_db <- function() {
 	FROM chorizon ORDER BY coiidref, hzdept_r ASC;"
 	
 	# setup connection to our pedon database
-	channel <- odbcConnect('nasis_local', uid='NasisSqlRO', pwd='Re@d0n1y')
+	channel <- odbcConnect('nasis_local', uid='NasisSqlRO', pwd='nasisRe@d0n1y')
 	
 	# exec query
 	d <- sqlQuery(channel, q, stringsAsFactors=FALSE)
